OutputProcessor

Trait OutputProcessor 

pub trait OutputProcessor: Send + Sync {
    // Required method
    fn process(&self, output: String) -> String;
}
Trait for processing tool output before adding it to the message context.

Implementations MUST be sync (no I/O) and fast.

Required Methods

fn process(&self, output: String) -> String

Process a tool output string and return the (possibly modified) result.

Implementors